pub struct InitCommand {
pub force: bool,
pub preset: Option<String>,
pub output: Option<PathBuf>,
pub interactive: bool,
pub from_lockfile: bool,
}Fields
force: boolpreset: Option<String>output: Option<PathBuf>interactive: boolLaunch an interactive wizard to generate sbox.yaml
from_lockfile: boolAuto-detect the package manager from an existing lockfile in the current directory and generate a matching preset config (skips the wizard)